@@ -18,15 +18,15 @@ class connect:
             self.cache.pop(0)
 
         try:
-            r = open(f"{self.path}{self.name}.json", "r").read()
+            r = open(f"{self.path}{self.name}.cprt", "r").read()
         except FileNotFoundError:
-            w = open(f"{self.path}{self.name}.json", "w+").write("{}")
-            r = open(f"{self.path}{self.name}.json", "r").read()
+            w = open(f"{self.path}{self.name}.cprt", "w+").write("{}")
+            r = open(f"{self.path}{self.name}.cprt", "r").read()
 
         self.database = ujson.loads(r)
 
 
-    def get(self, *, printf=False):
+    def get(self, key=False, *, printf=False):
         """ Returns the self.database dictionary.
 
             Arguments:
@@ -34,33 +34,25 @@ class connect:
 
             Return: dict
         """
-        if printf: print(self.database)
-        return self.database
+        if not key:
+            if printf: print(self.database)
+            return self.database
+        else:
+            if type(key) is str:
+                if printf: print(self.database[key])
+                return self.database[key]
+            else:
+                keys = ""
+                for i in range(key.__len__()):
+                    keys += f"[\"{key[i]}\"]"
+                if printf: print(eval(f"self.database{keys}"))
+                return eval(f"self.database{keys}")
 
     def save(self):
         """ Saves the database dictionary to a file. """
-        return ujson.dump(self.database, open(f"{self.path}/{self.name}.json", "w+"), indent=4)
+        return ujson.dump(self.database, open(f"{self.path}{self.name}.cprt", "w+"), indent=4)
 
-    def get_item(self, key, *, printf=False):
-        """ Returns the key value.
-
-            Arguments:
-                key -- type: str or list
-                printf -- type: bool (default: False)
-
-            Return: all type
-        """
-        if type(key) is str:
-            if printf: print(self.database[key])
-            return self.database[key]
-        else:
-            keys = ""
-            for i in range(key.__len__()):
-                keys += f"[\"{key[i]}\"]"
-            if printf: print(eval(f"self.database{keys}"))
-            return eval(f"self.database{keys}")
-
-    def set_item(self, key, value):
+    def set(self, key=False, value=False):
         """ Sets the key value.
 
             Arguments:
@@ -69,17 +61,36 @@ class connect:
 
             Return: None
         """
-        if type(key) is str:
-            self.database[key] = value
-            self.cache.append({"key": key, "value": value})
+        if not value:
+            self.database = key
+            self.save()
         else:
-            keys = ""
-            for i in range(key.__len__()):
-                keys += f"[\"{key[i]}\"]"
-            exec(f"self.database{keys} = value")
-            self.cache.append({"key": key[-1], "value": value})
+            if type(key) is str:
+                self.database[key] = value
+                self.cache.append({"key": key, "value": value})
+            else:
+                keys = ""
+                for i in range(key.__len__()):
+                    keys += f"[\"{key[i]}\"]"
+                exec(f"self.database{keys} = value")
+                self.cache.append({"key": key[-1], "value": value})
+            self.save()
 
-    def del_item(self, key):
+    def append(self, key, value):
+        self.get(key).append(value)
+        self.save()
+
+    def plus(self, key, value):
+        result = self.get(key) + value
+        self.set(key, result)
+        self.save()
+
+    def minus(self, key, value):
+        result = self.get(key) - value
+        self.set(key, result)
+        self.save()
+
+    def delete(self, key):
         """ Deletes the key.
 
             Arguments:
@@ -94,6 +105,7 @@ class connect:
             for i in range(key.__len__()):
                 keys += f"[\"{key[i]}\"]"
             exec(f"del self.database{keys}")
+        self.save()
 
     def find_cache(self, key):
         """ Returns a list of caches with the specified key.
